@@ -7,7 +7,7 @@ from astrape.utilities.utils_lightning import *
 from astrape.models.models_lightning import *
 from astrape.base.model_base import *
 import pytorch_lightning as pl
-from pytorch_lightning import LightningDataModule, loggers as pl_loggers
+from pytorch_lightning import loggers as pl_loggers
 from sklearn.model_selection import  train_test_split
 from sklearn.metrics import roc_auc_score
 import numpy as np
